==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/quicksight/kotlin/inputs/DashboardDashboardPublishOptionsDataPointTooltipOptionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.quicksight.kotlin.inputs

import com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsDataPointTooltipOptionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property availabilityStatus Availability status. Possibles values: ENABLED, DISABLED.
 */
public data class DashboardDashboardPublishOptionsDataPointTooltipOptionArgs(
    public val availabilityStatus: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsDataPointTooltipOptionArgs> {
    override fun toJava():
        com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsDataPointTooltipOptionArgs =
        com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsDataPointTooltipOptionArgs.builder()
            .availabilityStatus(availabilityStatus?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DashboardDashboardPublishOptionsDataPointTooltipOptionArgs].
 */
@PulumiTagMarker
public class DashboardDashboardPublishOptionsDataPointTooltipOptionArgsBuilder internal
constructor() {
    private var availabilityStatus: Output<String>? = null

    /**
     * @param value Availability status. Possibles values: ENABLED, DISABLED.
     */
    @JvmName("xcxpljixexvjeqfr")
    public suspend fun availabilityStatus(`value`: Output<String>) {
        this.availabilityStatus = value
    }

    /**
     * @param value Availability status. Possibles values: ENABLED, DISABLED.
     */
    @JvmName("jcxsqxaxfgixknme")
    public suspend fun availabilityStatus(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.availabilityStatus = mapped
    }

    internal fun build(): DashboardDashboardPublishOptionsDataPointTooltipOptionArgs =
        DashboardDashboardPublishOptionsDataPointTooltipOptionArgs(
            availabilityStatus = availabilityStatus,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/quicksight/kotlin/inputs/DashboardDashboardPublishOptionsDataPointTooltipOptionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.quicksight.kotlin.inputs

import com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsDataPointTooltipOptionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property availabilityStatus Availability status. Possibles values: ENABLED, DISABLED.
 */
public data class DashboardDashboardPublishOptionsDataPointTooltipOptionArgs(
    public val availabilityStatus: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsDataPointTooltipOptionArgs> {
    override fun toJava(): com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsDataPointTooltipOptionArgs =
        com.pulumi.aws.quicksight.inputs.DashboardDashboardPublishOptionsDataPointTooltipOptionArgs.builder()
            .availabilityStatus(availabilityStatus?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DashboardDashboardPublishOptionsDataPointTooltipOptionArgs].
 */
@PulumiTagMarker
public class DashboardDashboardPublishOptionsDataPointTooltipOptionArgsBuilder internal constructor() {
    private var availabilityStatus: Output<String>? = null

    /**
     * @param value Availability status. Possibles values: ENABLED, DISABLED.
     */
    @JvmName("mplmkmlnxoqiypuk")
    public suspend fun availabilityStatus(`value`: Output<String>) {
        this.availabilityStatus = value
    }

    /**
     * @param value Availability status. Possibles values: ENABLED, DISABLED.
     */
    @JvmName("eyindmerogwuqbkt")
    public suspend fun availabilityStatus(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.availabilityStatus = mapped
    }

    internal fun build(): DashboardDashboardPublishOptionsDataPointTooltipOptionArgs =
        DashboardDashboardPublishOptionsDataPointTooltipOptionArgs(
            availabilityStatus = availabilityStatus,
        )
}
